Please replace the csvs in folder "csvs" by the csvs you want to reformat. 
The ones present in the folder are csvs meant for testing.

To run the script on command line without installing the package: 
"python3 reformat.py -From <folder with old format csvs> -To <folder for new formaat csvs>"

*need a python version >= 3.6